@@ -1,5 +1,7 @@
 ( cd opt/kde/share/doc/HTML/en/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kgamma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kgamma ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kolourpaint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kolourpaint ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kruler ; rm -rf common )
